/*
	Copyright (c) 2004 Jonatan Kronqvist

	Permission is hereby granted, free of charge, to any person obtaining a
	copy of this software and associated documentation files (the "Software"),
	to deal in the Software without restriction, including without limitation
	the rights to use, copy, modify, merge, publish, distribute, sublicense,
	and/or sell copies of the Software, and to permit persons to whom the
	Software is furnished to do so, subject to the following conditions:

	The above copyright notice and this permission notice shall be included in
	all copies or substantial portions of the Software.

	THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
	FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
	AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
	LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
	FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
	IN THE SOFTWARE.
*/


#include "connection.h"


bluetooth_connection::bluetooth_connection()
{
	m_port_handle = NULL;
}


bool bluetooth_connection::connect()
{
	string8 tmpstr ("Connecting to serial port ");
	tmpstr.add_string(m_port);
	console::info(tmpstr);
	
	string8 port ("\\\\.\\");
	port.add_string(m_port);

	m_port_handle = uCreateFile(port,
								GENERIC_READ|GENERIC_WRITE,
								0,
								NULL,
								OPEN_EXISTING,
								0,
								NULL);
	if (m_port_handle == INVALID_HANDLE_VALUE)
		return false;

	COMMTIMEOUTS timeouts;
	memset(&timeouts, 0, sizeof(timeouts));
	timeouts.WriteTotalTimeoutConstant = 500;
	timeouts.WriteTotalTimeoutMultiplier = 10;
	if(SetCommTimeouts(m_port_handle, &timeouts))
		console::info("Connected.");
	else
		console::error("Couldn't set timeouts on port, check your settings");
	return true;
}


void bluetooth_connection::disconnect()
{
	if(m_port_handle != NULL) {
		CloseHandle(m_port_handle);
		m_port_handle = NULL;
	}
}


int bluetooth_connection::send(void *data, int length)
{
	DWORD byteswritten;
	WriteFile(m_port_handle, (LPCVOID) data, length, &byteswritten, NULL);
	return byteswritten;
}


int bluetooth_connection::read(void *dest, int length)
{
	DWORD bytesread;
	ReadFile(m_port_handle, (LPVOID) dest, length, &bytesread, NULL);
	return bytesread;
}


int bluetooth_connection::send(buffer &buf)
{
	DWORD byteswritten;
	WriteFile(m_port_handle, (LPCVOID) buf.get_ptr(), buf.length(), &byteswritten, NULL);
	return byteswritten;
}


void bluetooth_connection::set_parameter(string8 str)
{
	m_port = str;
}
